@@ -426,9 +426,9 @@ void DBH_genkey2(unsigned char * numero,unsigned char orden,unsigned int n)
 void DBH_settempdir(char *dir)
 {
  if (!dir) return;
- if (!DBH_tempdir) free(DBH_tempdir);
+ if (DBH_tempdir != NULL) free(DBH_tempdir);
  DBH_tempdir=(char *)malloc(strlen(dir)+1); 
- if (!DBH_tempdir) {WARNING1; return;}
+ if (DBH_tempdir == NULL) {WARNING1; return;}
  strcpy(DBH_tempdir,dir);
 }
 /*******************************************************************/
